import requests
import logging

from p2.agent.cronjob import Cronjob

__version__ = '0.1.6'

class Client:

    def __init__(self, p2_agent_endpoint, timeout:int = 10):
        self.log = logging.getLogger(__name__)
        self.p2_agent_endpoint = p2_agent_endpoint
        self.timeout = timeout

    def get_cronjobs(self, context):
        url = self.p2_agent_endpoint+'/k8s/cronjobs/'+context
        try:
            resp = requests.get( url, timeout=self.timeout)
            return resp.json() if (resp.status_code == 200) else None
        except requests.exceptions.RequestException as e:
            self.log.error("Error getting cronjobs {}".format(e))
            return None

    def create_cronjob(self, context:str, cronjob:Cronjob):
        url = self.p2_agent_endpoint+'/k8s/cronjob/'+context+'/'+cronjob.id
        try:
            resp = requests.post( url,
                    json=cronjob.__dict__,
                    timeout=self.timeout)
            if (resp.status_code == 201):
                return resp.json()
            else:
                raise Exception(
                        "Error creating cronjob {}, status code: {}".format(
                            cronjob.id, resp.status_code))
        except requests.exceptions.RequestException as e:
            self.log.error("Error creating cronjob: {}".format(e))
            raise e

    def delete_cronjob(self, context:str, id:str):
        url = self.p2_agent_endpoint+'/k8s/cronjob/'+context+'/'+id
        try:
            resp = requests.delete(url, timeout=self.timeout)
            if (resp.status_code == 200):
                return resp.json()
            else:
                raise Exception(
                        "Error deleting cronjob {}, status code: {}".format(
                            id, resp.status_code))
        except requests.exceptions.RequestException as e:
            self.log.error("Error deleting cronjob: {}".format(e))
