#!/usr/bin/env python
import logging
import os
import unittest
from uuid import uuid1
from pprint import pprint

from p2.agent.client import Client
from p2.agent.cronjob import Cronjob
from p2.tools.prepare_db import setUpDB, tearDownDB

logging.basicConfig(level=logging.INFO)

class TestAgentClient(unittest.TestCase):

    def setUp(self):
        logging.basicConfig(level=logging.DEBUG)
        self.log = logging.getLogger(__name__)
        self.log.debug("setting up...")
        setUpDB()

        p2_agent_url = os.environ.get('P2_AGENT_URL', 'http://localhost:5000/agent')
        self.client = Client(p2_agent_url)

    def tearDown(self):
        tearDownDB()

    def test_get_cronjobs(self):
        self.test_create_cronjob()
        cronjobs = self.client.get_cronjobs('minikube')
        self.assertIsNotNone(cronjobs)
        self.assertGreater(len(cronjobs),0)

    def test_create_cronjob(self):
        try:
            id = str(uuid1())[:8]
            cronjob = Cronjob(
                    id = id,
                    crontab = '0 0 * * *',
                    filename = 'exp_1'
                    )
            ret = self.client.create_cronjob('minikube', cronjob)
            self.assertEqual(ret, id)
        except Exception as e:
            self.log.exception("Error creating cronjob")
